@@ -39,8 +39,8 @@ def push(project, message, retries=2, container=None):
         if retry == '' or retry == 'y':
             push(project, message, retries-1, container)
         elif retry == 'n':
-			container.remove()            
-			exit("Push command failed")
+            container.remove()
+            exit("Push command failed")
     push_schema(project, container)
     container.remove()
 
@@ -61,8 +61,7 @@ def push_schema(project, container):
         exit(1)
 
     push_data = {'message': container.message or 'NO COMMIT MESSAGE',
-                 'image_data': {'id': project.docker_registry_name + '/' + container.user + '/' + project.name,
-                                'tag': container.tag},
+                 'image_data': {'id': container.repository, 'tag': container.tag},
                  'wrappers': wrapper_data}
     if project.schema_server_url:
         url = push_url(project, container.user)
@@ -96,5 +95,4 @@ def check_container_push(container, retries=2):
             logging.debug('Image pushed but not taged. Trying again: Retry left: %s' % str(retries))
             container.push()
             return check_container_push(container, retries-1)
-    return False
 
