@@ -1,20 +1,15 @@
 import logging
 
 import re
-import requests
-import base64
-import os
-import json
+from sys import stdout
 
 from subprocess import Popen
 from docker.auth.auth import load_config
 
-from sbdk.auth import login
+from sbdk.auth import login, store_credentials
 from sbdk.error import SbdkError
 
 
-
-DOCKER_CONFIG_FILENAME = '.dockercfg'
 ALLOWED_CHARS_RE = re.compile('^[a-z0-9]$')
 
 
@@ -35,28 +30,6 @@ def repo_name(project, user):
     return ret
 
 
-def store_credentials(docker_registry_name, username, password, cfg, email=None):
-    email = email or '%s@example.com' % username
-
-    def convert_to_dockercfg(cfg):
-        def encode_auth(username, password):
-            return base64.b64encode(username + b':' + password)
-
-        dockercfg = {}
-        for repo, auth in cfg.iteritems():
-            dockercfg[repo] = {'auth': encode_auth(auth['username'], auth['password']), 'email': auth['email']}
-        return dockercfg
-
-    config_file = os.path.join(os.environ.get('HOME', '.'), DOCKER_CONFIG_FILENAME)
-    if not cfg.get(docker_registry_name, None):
-        cfg[docker_registry_name] = {}
-    cfg[docker_registry_name]['username'], cfg[docker_registry_name]['password'], cfg[docker_registry_name]['email'] \
-        = username, password, email
-
-    with open(config_file, 'w') as outfile:
-        json.dump(convert_to_dockercfg(cfg), outfile)
-
-
 class Container(object):
 
     def __init__(self, docker_client, project, container,
@@ -137,18 +110,17 @@ class Container(object):
     def push(self):
         if not self.image:
             raise SbdkError("Container image not committed yet!")
-
-        self.docker.push(self.repository)
+        push = Popen(['docker', 'push', self.repository], stdout=stdout)
+        push.wait()
 
     def load_credentials(self, renew=False):
         cfg = load_config()
         if renew or not cfg:
             self._user, self._token = login(self.project)
             store_credentials(self.project.docker_registry_url, self._user, self._token, cfg)
-
         else:
-            self._user = cfg['username']
-            self._token = cfg['password']
+            self._user = cfg[self.project.docker_registry_url]['username']
+            self._token = cfg[self.project.docker_registry_url]['password']
 
     @property
     def tag(self):
