@@ -25,7 +25,7 @@ class Runner(object):
         self.docker_config = kwargs
         self.last_container = None
 
-    def run(self, command):
+    def run(self, command, entrypoint=None):
         volumes = {'/sb': {}, Runner.WORKING_DIR: {}}
         volumes.update(self.docker_config.pop('Volumes', {}))
         binds = {self.sb_dir: "/sb:rw",
@@ -36,6 +36,8 @@ class Runner(object):
         config['Volumes'] = volumes
         config['WorkingDir'] = Runner.WORKING_DIR
         config['Dns'] = self.dns
+        if entrypoint != None:
+            config['Entrypoint'] = self.project.docker_entrypoint
         #config['PortSpecs'] = ['22']
 
         config.update(self.docker_config)
@@ -48,7 +50,10 @@ class Runner(object):
                 logging.info("Trying to fetch image %s" % self.image_id)
                 repo, tag = parse_repository_tag(self.image_id)
                 self.client.pull(repo, tag)
-                self.image_id = find_image(self.client, repo, tag)
+                image = find_image(self.client, repo, tag)
+                if image is None:
+                    raise
+                self.image_id = image['Id']
                 config['Image'] = self.image_id
                 cont = self.client.create_container_from_config(config)
             else:
@@ -57,8 +62,11 @@ class Runner(object):
         self.last_container = Container(self.client, self.project, cont)
         return self.last_container
 
-    def run_and_print(self, command, remove=False):
-        cont = self.run(command)
+    def run_and_print(self, command, remove=False, test=False):
+        if test:
+            cont = self.run(command, entrypoint=self.project.docker_entrypoint)
+        else:
+            cont = self.run(command)
 
         def handler(signum, frame):
             logging.info('Received %s: %s', signum, frame)
@@ -83,29 +91,29 @@ class Runner(object):
     def run_install(self):
         return self.run(shlex.split(self.cmd_install))
 
-    def run_wrapper(self, input_path, cwd=None):
+    def run_wrapper(self, input_path, cwd=None, remove=True):
         run_full = self.base_cmd + ['run-full', '-i', input_path]
         if cwd:
             run_full += ['--cwd', cwd]
-        self.run_and_print(multi_command(self.cmd_install, run_full), remove=True)
+        self.run_and_print(multi_command(self.cmd_install, run_full), remove=remove)
 
-    def run_job(self, input_path, output_path, cwd=None):
+    def run_job(self, input_path, output_path, cwd=None, remove=True):
         cli_run = self.base_cmd + ['run', '-i', input_path, '-o', output_path]
         if cwd:
             cli_run += ['--cwd', cwd]
         cmd = multi_command(self.cmd_install, cli_run)
-        self.run_and_print(cmd, remove=False)
+        self.run_and_print(cmd, remove=remove)
 
-    def run_tests(self, wrapper):
+    def run_tests(self, wrapper, remove=True):
         cmd = multi_command(self.cmd_install, ['nosetests', wrapper])
-        self.run_and_print(cmd, remove=False)
+        self.run_and_print(cmd, remove=remove, test=True)
 
-    def schema(self, output=None):
+    def schema(self, output=None, remove=True):
         extra = ['--output', output] if output else []
         name = self.project.name
         cli_schema = self.base_cmd + ['schema'] + (['--package', name] if name else []) + extra
         cmd = multi_command(self.cmd_install, cli_schema)
-        self.run_and_print(cmd, remove=False)
+        self.run_and_print(cmd, remove=remove)
 
 
 class ImageRunner(Runner):
@@ -116,29 +124,29 @@ class ImageRunner(Runner):
         info = docker_client.inspect_image(image_id)
         self.base_cmd = info['config']['Cmd']
 
-    def run_wrapper(self, input_path, cwd=None):
+    def run_wrapper(self, input_path, cwd=None, remove=True):
         run_full = self.base_cmd + ['run-full', '-i', input_path]
         if cwd:
             run_full += ['--cwd', cwd]
-        self.run_and_print(run_full)
+        self.run_and_print(run_full, remove=remove)
 
-    def run_job(self, input_path, output_path, cwd=None):
+    def run_job(self, input_path, output_path, cwd=None, remove=True):
         run = self.base_cmd + ['run', '-i', input_path, '-o', output_path]
         if cwd:
             run += ['--cwd', cwd]
-        self.run_and_print(run)
+        self.run_and_print(run, remove=remove)
 
-    def run_tests(self, wrapper):
-        self.run_and_print(['nosetests', wrapper])
+    def run_tests(self, wrapper, remove=True):
+        self.run_and_print(['nosetests', wrapper], remove=remove)
 
     def run_install(self):
         raise NotImplementedError("Method 'run_install' not implemented for class ImageRunner.")
 
-    def schema(self, output=None):
+    def schema(self, output=None, remove=True):
         name = self.project.name if self.project else None
         cmd = self.base_cmd + ['schema'] + (['--package', name] if name else [])
         cmd += ['--output', output] if output else []
-        self.run_and_print(cmd)
+        self.run_and_print(cmd, remove=remove)
 
 
 def make_config(image, command):
