@@ -50,7 +50,7 @@ class Tassadar(Executor):
         except Exception as e:
             msg = get_exception_message(e)
             logging.exception('Job failed: %s', msg)
-            raise JobException(e)
+            raise JobException(msg)
         return result if result is not None else Outputs(wrp.outputs.__json__())
 
     def resolve(self, val):
