@@ -164,9 +164,10 @@ class Process(object):
                         self.stdout._callback(ready)
                         self.stderr._callback(ready)
             level = logging.WARN if self.exit_code else logging.INFO
-            logging.log(level, 'Process finished with exit code %s: %s', self.exit_code, self.cmd_line)
+            message = 'Process finished with exit code %s: %s', self.exit_code, self.cmd_line
+            logging.log(level, message)
             if self.exit_code:
-                raise SubprocessExecutionException(self)
+                raise SubprocessExecutionException(self, message)
         finally:
             self._close()
         return self
