@@ -1,4 +1,4 @@
-from sbgsdk.wrapper import Wrapper, _get_method_requirements
+from sbgsdk.wrapper import Wrapper, _get_method_requirements, Resources
 
 
 error = NotImplementedError('Methods split, work and merge must be overridden.')
@@ -6,14 +6,14 @@ error = NotImplementedError('Methods split, work and merge must be overridden.')
 
 class ScatterGatherWrapper(Wrapper):
     def _entry_point(self):
-        return self.job('_split', requirements=_get_method_requirements(self, 'split'), name='split')
+        return self.job('_split', requirements=self.get_split_requirements(), name='split')
 
     def _split(self):
         args_list = self.split()
-        jobs = [self.job('_work', requirements=_get_method_requirements(self, 'work'),
+        jobs = [self.job('_work', requirements=self.get_work_requirements(args),
                          name='work_%s' % ndx, args={'job': args})
                 for ndx, args in enumerate(args_list)]
-        return self.job('_merge', name='merge', requirements=_get_method_requirements(self, 'merge'),
+        return self.job('_merge', name='merge', requirements=self.get_merge_requirements(),
                         args={'job_results': jobs})
 
     def _work(self, job):
@@ -30,3 +30,12 @@ class ScatterGatherWrapper(Wrapper):
 
     def merge(self, job_results):
         raise error
+
+    def get_split_requirements(self):
+        return _get_method_requirements(self, 'split') or Resources()
+
+    def get_work_requirements(self, job):
+        return _get_method_requirements(self, 'work') or Resources()
+
+    def get_merge_requirements(self):
+        return _get_method_requirements(self, 'merge') or Resources()
\ No newline at end of file
